API Reference - Models
======================

This section documents the Pydantic models used throughout the framework.

Service Configuration
---------------------

.. autoclass:: socialseed_e2e.core.models.ServiceConfig
   :members:
   :undoc-members:
   :show-inheritance:

Test Context
------------

.. autoclass:: socialseed_e2e.core.models.TestContext
   :members:
   :undoc-members:
   :show-inheritance:

Retry Configuration
-------------------

.. autoclass:: socialseed_e2e.core.base_page.RetryConfig
   :members:
   :undoc-members:
   :show-inheritance:

Rate Limit Configuration
------------------------

.. autoclass:: socialseed_e2e.core.base_page.RateLimitConfig
   :members:
   :undoc-members:
   :show-inheritance:

Request Log
-----------

.. autoclass:: socialseed_e2e.core.base_page.RequestLog
   :members:
   :undoc-members:
   :show-inheritance:

Exceptions
----------

.. autoclass:: socialseed_e2e.core.base_page.BasePageError
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: socialseed_e2e.core.config_loader.ConfigError
   :members:
   :undoc-members:
   :show-inheritance:
